#
# spec file for package siproxd
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif
%define piddir          %_rundir/siproxd/
%define regdir          /var/lib/siproxd/
%define siproxduser     siproxd
%define siproxdgroup    siproxd

Name:           siproxd
Version:        0.8.3
Release:        4.2
Summary:        A SIP masquerading proxy with RTP support
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            http://siproxd.sourceforge.net/
Source0:        https://sourceforge.net/projects/siproxd/files/siproxd/%{version}/siproxd-%{version}.tar.gz
Source1:        susefirewall2.%{name}
Source2:        %name.init.in
Source3:        %name.logrotate
Source4:        %name.8.gz
Source5:        syslog-ng.conf.addon
Source6:        siproxd.service
# PATCH-FIX-FOR-UPSTREAM -- http://sourceforge.net/tracker/?func=detail&aid=3086321&group_id=60374&atid=493974
#Code to detect libltdl was placed before the code that populates the library locations.
#This caused libltdl to be undetected even after it was installed locally.
#The patch moves the library detection code in front of libltdl detection
#and also adds standard library (and include) locations, ie. /usr/local/lib
#After applying the patch, autogen.sh needs to be run (which, among other things, rebuilds "configure").
Patch0:         siproxd-libs.patch
Patch1:         siproxd.plugin_fix_bogus_via.c.patch
# PATCH-FIX-UPSTREAM https://sourceforge.net/p/siproxd/bugs/65/
Patch2:         reproducible.patch
BuildRequires:  docbook-utils
BuildRequires:  libosip2-devel
BuildRequires:  libtool
BuildRequires:  sqlite3-devel
BuildRequires:  texlive-courier
BuildRequires:  texlive-dvips
BuildRequires:  texlive-ec
BuildRequires:  texlive-helvetic
BuildRequires:  texlive-jadetex
BuildRequires:  texlive-times
%if %suse_version > 1315
BuildRequires:  texlive-kpathsea
BuildRequires:  texlive-metafont
BuildRequires:  texlive-wasy
%endif
Requires:       logrotate
Requires(pre):  %{_sbindir}/groupadd
Requires(pre):  %{_sbindir}/useradd
%if %suse_version <= 1500
Suggests:       SuSEfirewall2
%endif

%description
Siproxd is an proxy/masquerading daemon for the SIP protocol. It handles
registrations of SIP clients on a private IP network and performs
rewriting of the SIP message bodies to make SIP connections possible
via an masquerading firewall. It allows SIP clients (like kphone,
linphone) to work behind an IP masquerading firewall or router.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/Other

%description doc
HTML and PDF documentation for %{name}

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

cp %{S:5} .

%build
autoreconf --install --force
CFLAGS="%{optflags} -fno-strict-aliasing"
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
mv %{buildroot}%{_sysconfdir}/%{name}.conf.example \
   %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

%if %suse_version <= 1500
install -d %{buildroot}/%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/
install -m 644 %{S:1} %{buildroot}/%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}
%endif

install -d %{buildroot}/%{_sysconfdir}/logrotate.d/
install -m 0644 %{S:3} %{buildroot}/%{_sysconfdir}/logrotate.d/%{name}

install -d %{buildroot}/%{_datadir}/%{name}/scripts
install %{S:2} %{buildroot}/%{_datadir}/%{name}/scripts/%{name}
install -d %{buildroot}/%{_unitdir}
install -m 644 %{S:6} %{buildroot}/%{_unitdir}
sed -i "s#@%{name}_PIDDIR@#%{_rundir}/%{name}#" %{buildroot}%{_datadir}/%{name}/scripts/%{name}
install -d %buildroot/%{_sbindir}
ln -s %{_sbindir}/service %buildroot/%{_sbindir}/rc%{name}

mkdir -p %buildroot%_mandir/man8
install -m 0644 %{S:4} %{buildroot}/%{_mandir}/man8/%name.8.gz
#
sed -i -e "s@nobody@%{siproxduser}@" %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
sed -i -e "s@nobody@%{siproxduser}@" %{buildroot}%{_datadir}/%{name}/scripts/%{name}
#
# Directory needs to exist for packaging
mkdir -p %{buildroot}/%{_rundir}/%{name}

# cleanup
rm -f %{buildroot}/%{_sysconfdir}/siproxd_passwd.cfg
rm -f %{buildroot}/%{_libdir}/%{name}/*.a
rm -rf %{buildroot}/usr/share/doc/%{name}

%post
/sbin/ldconfig
%service_add_post siproxd.service

%pre
%service_add_pre siproxd.service
getent group %{siproxdgroup} >/dev/null || \
	%{_sbindir}/groupadd -r %{siproxdgroup}
getent passwd %{siproxduser} >/dev/null || \
	%{_sbindir}/useradd -r -g %{siproxdgroup} -s /bin/false \
	-c "Siproxd user" -d %{_rundir}/%{name} %{siproxduser}

%postun
%service_del_postun siproxd.service
/sbin/ldconfig

%preun
%service_del_preun siproxd.service

%files
%license COPYING
%doc README AUTHORS ChangeLog syslog-ng.conf.addon
%doc doc/siproxd.conf.example doc/siproxd_passwd.cfg doc/FAQ doc/KNOWN_BUGS doc/sample_*
%attr(0755,root,root) %{_libdir}/%{name}/
%{_sbindir}/rc%name
%{_sbindir}/%name
%{_datadir}/%{name}
%attr(0755,root,root) %{_datadir}/%{name}/scripts/%{name}
%config %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%{_unitdir}
%{_unitdir}/siproxd.service

%if %suse_version <= 1500
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}
%endif

%_mandir/man8/%name.8*

%dir %_sysconfdir/%name
#make rpm know about a directory but do not package it
%attr(0750,%{siproxduser},root) %ghost %{_rundir}/%{name}

%files doc
%doc doc/html/* doc/pdf/*

%changelog
* Sun Sep  3 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Fri Apr  8 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop texlive-texconfig BuildRequires: package no longer exists
  and the build succeeds without it too.
* Wed Nov 17 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * siproxd.service
* Wed May 19 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.8.3
  * mostly bugfixes and performance improvements
  * Upgrade Notes 0.8.2 to 0.8.3:
  * Merge the configuration file
  * New plugins:
  * plugin_stats: write some statistics about currently active calls
  * plugin_blacklist: new plugin to block UACs that cause excessive
    failures during REGISTER attempts
- Drop upstream fixed siproxd-log.c.patch and
  siproxd-multiple-definition.patch
- SPEC file drop parts for outdated openSUSE / SLE versions
* Mon Nov 23 2020 Franck Bui <fbui@suse.com>
- Drop dep on %%insserv_prereq as it's not needed since the switch to a
  service unit
* Wed Oct  7 2020 ro@suse.de
- drop explicit buildreq for libosip2, already have libosip2-devel
- mark COPYING as license, drop defattr lines
* Tue Jul 28 2020 Thorsten Kukuk <kukuk@suse.com>
- Don't install SuSEfirewall2 service files, it's gone.
* Mon Jun  8 2020 ro@suse.de
- add patch siproxd-multiple-definition.patch
  to fix compilation with recent gcc
  accessctl.o:./src/accessctl.c:37: multiple definition of
  configuration struct
* Fri Mar 15 2019 Jan Engelhardt <jengelh@inai.de>
- Do not hide errors from useradd.
- Replace %%__-type macro indirections.
- Remove redundant %%clean section.
* Fri Mar 15 2019 josef.moellers@suse.com
- Added systemd support
  [bsc#1116037, siproxd.service]
* Mon Jul  3 2017 ro@suse.de
- update to 0.8.2
  - We do now support dealing with anonymous calls
  - Support for SIP Trunks
  - Various interoperability issues have been resolved
  - various bugfixes have been implemented
- drop dejitter-implicit-func-fix.patch (obsolete)
- drop 0001-plugins_implicit_func_fix.patch (obsolete)
- add buildrequires for some texlive packages to build docu
* Mon Apr 24 2017 idonmez@suse.com
- Use %%insserv_prereq for insserv dependency
* Thu Apr 20 2017 ro@suse.de
- add prereq for insserv
* Mon Feb 23 2015 dimstar@opensuse.org
- Drop libltdl BuildRequires: this is part of libtools and the old
  separate library has been removed from Factory.
* Wed Sep 24 2014 sfalken@opensuse.org
- Added 0001-plugins_implicit_func_fix.patch to clear post-build-
  check failure
* Mon Jul 21 2014 ro@suse.de
- use _rundir macro to fix build against factory
* Tue Jul  9 2013 toganm@opensuse.org
- Fix build errors
  * Fix implicit functions build error by the following patch
    dejitter-implicit-func-fix.patch
  * renumbered patches
  * Remove INSTALL file from docs
* Tue Nov 20 2012 dimstar@opensuse.org
- Fix useradd invocation: -o is useless without -u and newer
  versions of pwdutils/shadowutils fail on this now.
* Tue Jul 24 2012 werner@suse.de
- Add missing font
* Tue Jul 10 2012 werner@suse.de
- Make it build with latest TeXLive 2012 with new package layout
* Mon Mar 19 2012 ro@suse.de
- switch from user nobody to own user siproxd (bnc#710608)
* Thu Aug 18 2011 ro@suse.de
- update to 0.8.1
  - new Plugins: plugin_prefix: add a prefix on outgoing calls
    plugin_regex: regular expression rewriting (To header)
    for outgoing calls
  - adjustable pthrad stack size (smaller memory footprint on small
    embedded systems like OpenWRT routers)
  - plus various bugfixes
  - Upgrade Notes 0.8.0 to 0.8.1:
    merge your configuration file siproxd.conf (new config options)
- drop "Should-Start: SuSEfirewall2_setup" from init script
  (SuSEfirewall2_setup is configured as _last_ script to be started)
* Fri Jul  1 2011 aj@suse.de
- Fix build, we need /var/run/siproxd created to package it as
  ghost.
* Sat Apr 16 2011 toganm@opensuse.org
- Added syslog-ng.conf.addon as an example for use with syslog-ng
* Tue Jan 18 2011 toganm@opensuse.org
- update to 0.8.0
  * added logrotate to Requires
  * SuSEfirewall2.siproxd for services
  * siproxd-libs.patch
    Code to detect libltdl was placed before the code that populates
    the library locations.
    This caused libltdl to be undetected even after it was installed
    locally. The patch moves the library detection code in front of
    libltdl detection    and also adds standard library (and include)
    locations, ie. /usr/local/lib After applying the patch, autogen.sh
    needs to be run (which, among other things, rebuilds "configure").
  * siproxd-log.c.patch
    patch from debian use logger not user
  * siproxd-plugin_shortdial.c.patch
    fixes warning comparison is always false due to limited range of data type
  * siproxd-siproxd.c.patch
    fixes the warning by using a more portable method of printing size_t values
  * siproxd-sock.c.patch
    Fixes compile warning
  * siproxd-Makefile.am.patch
  * siproxd-configure.in.patch
    backported from 0.81.dev
  * removed siproxd-md5.patch as fixed in upstream
  * siproxd.plugin_fix_bogus_via.c.patch
  * added man page for siproxd
  * use CFLAGS -Wall only with GCC compiler (patch)
  * fixed UA masquerading which was always set ("foobar")- (patch
* Fri Apr  4 2008 ro@suse.de
- update to 0.7.0, no changes beside official release
* Thu Feb 28 2008 ro@suse.de
- fix build with current libosip2
* Sun Jan 13 2008 ro@suse.de
- update to snapshot version
  - Converting to use libosip2-3.x.x
    This means older libosip2 versions before 3.0.0
    are no longer supported and will fail to build!
- update to 0.6.1
  - DNS failure cache: do several attempts before blacklisting
  - Fix: Detach from controlling TTY if daemonized
  - Working on code that that will allow siproxd to use
    separate interfaces in its "in front of NAT router" setup.
    ( UA1[LAN0]--siproxd--LAN1--NAT--Internet--UA2 )
  - Small changes to compile again under OpenBSD.
- update to 0.6.0
  - Released 0.6.0
  - keep failed DNS attempts in cache for 10 minutes.
    This should protect from repeating DNS timeouts
    caused by broken DNS server (possible DOS)
  - added comment in siproxd.conf about hosts_allow_sip
  - some come cleanup in log.c (Bob Beers)
  - fixed an error in "my via" detection when using the
    "host_outbound" config directive
  - Some cleanup in dejitter code
  - Deal with PRACK requests (RFC3262)
  - Just discovered some patches originating from Debian
    project - included most of them as they make sense.
    (Hint: People, if you get fixes, please drop me a note
    and a .diff - I won't be biting you)
  - new feature: can masquerade User-agent header
  - new feature: can add ;rport to my own Via Headers
  - deal with locally running UAs on same host (inbound IF side)
  - Client-ID in RTP proxy is derived from Client IP address.
    This should fix an issue with unexpectedly timing-out RTP
    streams (actually too many RTP streams get started).
  - Hack to deal with Asterisks broken Alert-Info headers
    (Asterisk in some setups does include Alert-Info header
    without '<>'. Note, this is a configuration issue in
    Asterisk, not an Asterisk bug!)
  - Increased RTP buffer size
  - Various fixes due to a code review by Andrew Jones
  - route_determine_nexthop(): don't remove header
  - increased DNS cache
  - included RTCP support and a de-jitter feature
    (submitted by Hans Carlos Hofmann)
* Wed May 16 2007 ro@suse.de
- use libosip2-devel in buildrequires
* Tue Jun 20 2006 ro@suse.de
- update to 0.5.13 incorporating previous cvs fixes
* Fri Jun 16 2006 ro@suse.de
- update to 0.5.12
  Major changes since 0.5.11:
  A "Short-Dial" feature is now available.
  A number of bugfixes have been made. These include some issues
  with Grandstream phones and the "unregister at startup" option,
  as well as other issues with the expiration timeout.
- added current fixes from cvs (jun16th):
  - RTP timeout handling: allow unidirectional data w/o
    terminating connection after timeout.
  - Fixed compiling issue when building on MacOS (Georg Schwarz)
  - A number of correction in debugging code (James Henstridge)
  - REGISTER response generated from siproxd includes
    a Contact header.
  - some I64 architecture issues
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Aug  5 2005 cthiel@suse.de
- update to version 0.5.11
* Fri Feb  4 2005 ro@suse.de
- update to 0.5.10
* Tue Nov  9 2004 ro@suse.de
- update to 0.5.9
* Thu Jul 29 2004 ro@suse.de
- fix build after libosip update
* Sun Jun 27 2004 ro@suse.de
- update to 0.5.7
* Wed Apr 28 2004 ro@suse.de
- update to current version (0.5.5)
* Sun Mar  7 2004 ro@suse.de
- update to 0.5.4
* Mon Feb  2 2004 ro@suse.de
- update to 0.5.2
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Thu Nov 27 2003 ro@suse.de
- update to 0.5.0
- main binary moved to /usr/sbin
* Sun Oct 12 2003 ro@suse.de
- update to 0.4.1
* Fri Sep 26 2003 ro@suse.de
- update to 0.3.6b
* Tue Jun 10 2003 ro@suse.de
- created package (version 0.3.2)
